rückenwind
==========

A python web framework based on tornado, jinja2, babel.


Documentation
=============

Head over to `Read The Docs <http://ruckenwind.readthedocs.org/en/latest/>`_ and read the docs! Or build the docs from source using:

``sphinx-build -b html sphinx/ docs.html/``

and enjoy locally.

0.X
===

Currently the framework is still in development and it does not provide a stable API.  When the API stabalizes the version is incremented to 1.x

0.4.x
-----
The 0.4 branch introduces a new API and is incompatible with 0.3 in many details.


|travis_04|_  (0.4 branch)


.. |travis_04| image:: https://travis-ci.org/FlorianLudwig/rueckenwind.svg?branch=kill_rbus
.. _travis_04: https://travis-ci.org/FlorianLudwig/rueckenwind
